#
# Spec file for package sirikali
#
# Copyright © 2016 Francis Banyikwa <mhogomchungu@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

%global srcname SiriKali
%global srcurl  https://github.com/mhogomchungu/%{name}

Name:           sirikali
Version:        1.3.2
Release:        1%{?dist}
Summary:        GUI front end to encfs,cryfs,gocryptfs and securefs
License:        GPLv2+
URL:            http://mhogomchungu.github.io/%{name}

Source0:         %{srcurl}/releases/download/%{version}/%{srcname}-%{version}.tar.xz
# src/siritask.h:24:10: fatal error: task.h: No such file or directory
Source1:         https://raw.githubusercontent.com/mhogomchungu/%{name}/60a8fa5621a22aba66145e5c6c660201bf471f86/src/task.h
# TODO include Debian patches
# https://github.com/mhogomchungu/sirikali/pull/56

BuildRequires: cmake
BuildRequires: gcc-c++

BuildRequires: json-devel
BuildRequires: libgcrypt-devel
BuildRequires: pkgconfig(libsecret-1)
BuildRequires: pkgconfig(lxqt-wallet)

BuildRequires: pkgconfig(Qt5Core)
BuildRequires: pkgconfig(Qt5Gui)
BuildRequires: pkgconfig(Qt5Network)

BuildRequires: desktop-file-utils
Requires:      hicolor-icon-theme

Recommends:    fuse-encfs

%description
%{srcname} is a Qt/C++ GUI front end to encfs,cryfs,gocryptfs and securefs.


%prep
%autosetup -n%{srcname}-%{version}
# unbundle
pushd src/3rdParty
rm -rv json* lxqt_wallet
popd
sed -i -r 's:".*(json.hpp)":"\1":' CMakeLists.txt
sed -i 's:3rdParty/json:json:' src/%{name}.cpp
cp -p %{SOURCE1} src

%build
mkdir %{_target_platform}
pushd %{_target_platform}
%cmake .. -DQT5=true \
 -DNOKDESUPPORT=true -DNOSECRETSUPPORT=false \
 -DINTERNAL_LXQT_WALLET=false

%install
%make_install -C %{_target_platform}
chmod 644 %{buildroot}%{_datadir}/applications/%{name}.desktop
%find_lang %{name} --with-qt --all-name

%check
desktop-file-validate %{buildroot}%{_datadir}/applications/%{name}.desktop


%post
/bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    /bin/touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    /usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
/usr/bin/gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :


%files -f %{name}.lang
%license LICENSE COPYRIGHT GPLv*
%doc README.md ABOUT* changelog
%{_bindir}/%{name}*
%attr(644,-,-) %{_datadir}/applications/%{name}.desktop
%dir %{_datadir}/%{name}
%dir %{_datadir}/%{name}/translations
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/icons/%{name}.png
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/polkit-1/actions/*.policy
%{_mandir}/man1/%{name}*.1*


%changelog
* Sat Jan 13 2018 Raphael Groner <projects.rg@smart.ms> - 1.3.2-1
- new version
- drop BSD because unbundled json
- unbundle lxqt_wallet

* Tue Jul 11 2017 Raphael Groner <projects.rg@smart.ms> - 1.2.9-1
- new version
- unbundle json

* Mon Jun 12 2017 Builder <projects.rg@smart.ms> - 1.2.7.1.20170611git
- new version
- use git snapshot to include latest upstream patches
- include upstream patch to get full path of su binary
- distribute additonal files
- drop workaround for duplicated readme files
- fix length of line in description

* Sun Jun 04 2017 Raphael Groner <projects.rg@smart.ms> - 1.2.5-2
- fix duplication of license documentation files
- reorder explicit ownership of folders
- fix file attributes of desktop file
- add weak dependency to fuse-encfs

* Wed Mar 01 2017 Raphael Groner <projects.rg@smart.ms> - 1.2.5-1
- adopt for Fedora
